@@ -1,20 +1,22 @@
-#--------------------------------------------------------------------
+#····································································
 #   npsp-rules.R (library(npsp))
-#--------------------------------------------------------------------
+#····································································
 #   rule
 #   rule.binning              S3 methods
 #       rule.binning.default
 #
-#--------------------------------------------------------------------
+#····································································
 #    npsp es un software libre y viene sin GARANTIA ALGUNA.
 #    Usted puede redistribuirlo bajo ciertas circunstancias.
 #    Escriba 'license()' para detalles de distribucion.
 #
 #   (c) R. Fernandez-Casal
-#   Creation: Jul 2015                       Last revision: Aug 2015
-#--------------------------------------------------------------------
+#   Creation: Jul 2015
+#
+#   NOTE: Press Ctrl + Shift + O to show document outline in RStudio
+#····································································
 
-#--------------------------------------------------------------------
+#····································································
 #' npsp Rules
 #'
 #' Compute the number of classes for a histogram,
@@ -35,7 +37,7 @@
 #' The rule values (vector or scalar).
 #' @importFrom grDevices nclass.FD nclass.Sturges nclass.scott
 #' @export
-#--------------------------------------------------------------------
+#····································································
 rule <- function(x, d = 1, rule = c("Rice", "Sturges", "scott", "FD"), ...){
   rule <- match.arg(rule)
     res <- switch(rule,
@@ -46,14 +48,16 @@ rule <- function(x, d = 1, rule = c("Rice", "Sturges", "scott", "FD"), ...){
     return(res ^(1/d))
 }
 
-#--------------------------------------------------------------------
+#····································································
 #' @rdname npsp-internals
 #' @param  a  scale values.
 #' @param  b  exponent values.
 #' @keywords internal
 # @export
-#--------------------------------------------------------------------
-.rice.rule <- function(x, a = 2, b = 3, ...) ceiling(a * x ^ (1 / b))
+#····································································
+.rice.rule <- function(x, a = 2, b = 3, ...) {
+  ceiling(a * x ^ (1 / b))
+}
 # PENDENTE:
 # ["https://en.wikipedia.org/wiki/Histogram#Mathematical_definition"]
 # nb <- round(log(ny)/log(2) + 1) # ter en conta o num de dimensions?
@@ -62,7 +66,7 @@ rule <- function(x, d = 1, rule = c("Rice", "Sturges", "scott", "FD"), ...){
 # Regla de Scott K=(2n)^(1/3)
 # (4*n)^(2/5)
 
-#--------------------------------------------------------------------
+#····································································
 #' @rdname rule
 # @param  x  object used to select a method.
 # @param  ... further arguments passed to or from other methods.
@@ -70,10 +74,12 @@ rule <- function(x, d = 1, rule = c("Rice", "Sturges", "scott", "FD"), ...){
 #' \code{rule.binning} returns a vector with the suggested number of bins
 #' on each dimension.
 #' @export
-#--------------------------------------------------------------------
-rule.binning <- function(x, ...) UseMethod("rule.binning")
+#····································································
+rule.binning <- function(x, ...) {
+  UseMethod("rule.binning")
+}
 
-#--------------------------------------------------------------------
+#····································································
 #' @rdname rule
 #' @method rule.binning default
 #' @param  a  scale values.
@@ -81,7 +87,7 @@ rule.binning <- function(x, ...) UseMethod("rule.binning")
 #' @export
 #' @return
 #' \code{rule.binning.default} returns \code{rep(ceiling(a * nrow(x) ^ (1 / b)), d)}.
-#--------------------------------------------------------------------
+#····································································
 rule.binning.default <- function(x, d = ncol(x), a = 2, b = d + 1, ...) {
     x <- as.matrix(x)
     ny <- nrow(x)
@@ -91,7 +97,7 @@ rule.binning.default <- function(x, d = ncol(x), a = 2, b = d + 1, ...) {
 }
 
 
-#--------------------------------------------------------------------
+#····································································
 #' @rdname rule
 # @param  x  object used to select a method.
 # @param  ... further arguments passed to or from other methods.
@@ -99,16 +105,18 @@ rule.binning.default <- function(x, d = ncol(x), a = 2, b = d + 1, ...) {
 #' \code{rule.svar} returns the suggested number of bins
 #' for variogram estimation.
 #' @export
-#--------------------------------------------------------------------
-rule.svar <- function(x, ...) UseMethod("rule.svar")
+#····································································
+rule.svar <- function(x, ...) {
+  UseMethod("rule.svar")
+}
 
-#--------------------------------------------------------------------
+#····································································
 #' @rdname rule
 #' @method rule.svar default
 #' @return
 #' \code{rule.svar.default} returns \code{ceiling(a * (nrow(x)^2 / 4) ^ (1 / b))}.
 #' @export
-#--------------------------------------------------------------------
+#····································································
 rule.svar.default <- function(x, d = ncol(x), a = 2, b = d + 1, ...) {
     x <- as.matrix(x)
     ny <- nrow(x)
@@ -116,11 +124,11 @@ rule.svar.default <- function(x, d = ncol(x), a = 2, b = d + 1, ...) {
     return( .rice.rule(ny^2/4, a = a, b = b))
 }
 
-#--------------------------------------------------------------------
+#····································································
 #' @rdname rule
 #' @method rule.svar bin.den
 #' @export
-#--------------------------------------------------------------------
+#····································································
 rule.svar.bin.den <- function(x, ...) {
     # nlags <- round(2 * mean(dim(x)))
     # maxlag <- with(x$grid, 0.45*sqrt(sum(max - min)^2))     # 45% of largest lag
